@@ -41,8 +41,6 @@
 #' it must have the signature `function(x)` and return the perception probability of
 #' the difference `x` between the limiting magnitude and the meteor magnitude.
 #' If `x >= 15.0`, the function `perception.fun` should return a perception probability of `1.0`.
-#' If `log = TRUE` is specified, the logarithm of the perception probabilities
-#' must be returned.  
 #' The argument `perception.fun` is resolved using [match.fun].
 #'
 #' @return
@@ -53,6 +51,7 @@
 #'
 #' The length of the result is determined by `n` for `rvmgeom`, and by the maximum
 #' of the lengths of the numeric vector arguments for the other functions.
+#' All arguments are vectorized; standard R recycling rules apply.
 #'
 #' Since the distribution is discrete, `qvmgeom` and `rvmgeom` always return integer values.  
 #' `qvmgeom` may return `NaN` with a warning.
@@ -145,8 +144,9 @@ dvmgeom <- function(m, lm, r, log = FALSE, perception.fun = NULL) {
         p.geom <- rep(p.geom, length(m))
     }
 
-    offset <- 0.0
-    list2env(vmgeom.std(m, lm), environment())
+    std_res <- vmgeom.std(m, lm)
+    m <- std_res$m
+    offset <- std_res$offset
 
     f.density <- function(m, offset, p.geom) {
         m.max <- 15L
@@ -226,8 +226,9 @@ pvmgeom <- function(m, lm, r, lower.tail = TRUE, log = FALSE, perception.fun = N
         p.geom <- rep(p.geom, length(m))
     }
 
-    offset <- 0.0
-    list2env(vmgeom.std(m, lm), environment())
+    std_res <- vmgeom.std(m, lm)
+    m <- std_res$m
+    offset <- std_res$offset
 
     f.density <- function(m, offset, p.geom) {
         stats::dgeom(m, p.geom) * perception.fun(m + offset)
